@@ -467,6 +467,18 @@ public:
         dhcp_queue_control_ = dhcp_queue_control;
     }
 
+    /// @brief Returns DHCP multi threading information
+    /// @return pointer to the DHCP multi threading information
+    const isc::data::ConstElementPtr getDHCPMultiThreading() const {
+        return (dhcp_multi_threading_);
+    }
+
+    /// @brief Sets information about the dhcp multi threading
+    /// @param dhcp_multi_threading new dhcp multi threading information
+    void setDHCPMultiThreading(const isc::data::ConstElementPtr dhcp_multi_threading) {
+        dhcp_multi_threading_ = dhcp_multi_threading;
+    }
+
     /// @brief Returns pointer to the dictionary of global client
     /// class definitions
     ClientClassDictionaryPtr getClientClassDictionary() {
@@ -705,34 +717,6 @@ public:
         return (dhcp4o6_port_);
     }
 
-    /// @brief Sets the server thread count.
-    ///
-    /// @param threads value of the server thread count
-    void setServerThreadCount(uint32_t threads) {
-        server_threads_ = threads;
-    }
-
-    /// @brief Retrieves the server thread count.
-    ///
-    /// @return value of the server thread count
-    uint32_t getServerThreadCount() const {
-        return (server_threads_);
-    }
-
-    /// @brief Sets the server max thread queue size.
-    ///
-    /// @param size max thread queue size
-    void setServerMaxThreadQueueSize(uint32_t size) {
-        server_max_thread_queue_size_ = size;
-    }
-
-    /// @brief Retrieves the server max thread queue size.
-    ///
-    /// @return value of the max thread queue size
-    uint32_t getServerMaxThreadQueueSize() const {
-        return (server_max_thread_queue_size_);
-    }
-
     /// @brief Returns pointer to the D2 client configuration
     D2ClientConfigPtr getD2ClientConfig() {
         return (d2_client_config_);
@@ -930,6 +914,9 @@ private:
     /// @brief Pointer to the dhcp-queue-control information
     isc::data::ConstElementPtr dhcp_queue_control_;
 
+    /// @brief Pointer to the multi-threading information
+    isc::data::ConstElementPtr dhcp_multi_threading_;
+
     /// @brief Pointer to the dictionary of global client class definitions
     ClientClassDictionaryPtr class_dictionary_;
 
@@ -951,12 +938,6 @@ private:
     /// this socket is bound and connected to this port and port + 1
     uint16_t dhcp4o6_port_;
 
-    /// @brief The server thread count.
-    uint32_t server_threads_;
-
-    /// @brief The server max thread queue size.
-    uint32_t server_max_thread_queue_size_;
-
     /// @brief Stores D2 client configuration
     D2ClientConfigPtr d2_client_config_;
 
